@@ -5,3 +5,5 @@ from .pressure import *
 from .energy import *
 from .distance import *
 from .angular import *
+import unit_test
+assert unit_test
